import sys

from PyObjCTools.TestSupport import TestCase, min_os_level, min_sdk_level
import objc

if sys.maxsize > 2 ** 32:
    import PushKit

    class TestPKPushRegistryHelper(PushKit.NSObject):
        def pushRegistry_didReceiveIncomingPushWithPayload_forType_withCompletionHandler_(
            self, a, b, c, d
        ):
            pass

    class TestPKPushRegistry(TestCase):
        @min_os_level("10.15")
        def test_constants(self):
            self.assertIsInstance(PushKit.PKPushTypeFileProvider, str)

        @min_sdk_level("10.15")
        def test_methods(self):
            self.assertArgIsBlock(
                TestPKPushRegistryHelper.pushRegistry_didReceiveIncomingPushWithPayload_forType_withCompletionHandler_,  # noqa: B950
                3,
                b"v",
            )

        @min_sdk_level("10.15")
        def test_protocols(self):
            objc.protocolNamed("PKPushRegistryDelegate")



# This file is generated by objective.metadata
#
# Last update: Sun Mar 22 15:05:20 2020
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b


else:

    def sel32or64(a, b):
        return a


misc = {}
constants = """$PKPushTypeComplication$PKPushTypeFileProvider$PKPushTypeVoIP$"""
enums = """$$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"NSObject",
        b"pushRegistry:didInvalidatePushTokenForType:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"pushRegistry:didReceiveIncomingPushWithPayload:forType:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"pushRegistry:didReceiveIncomingPushWithPayload:forType:withCompletionHandler:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {
                2: {"type": b"@"},
                3: {"type": b"@"},
                4: {"type": b"@"},
                5: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}},
                    },
                    "type": b"@?",
                },
            },
        },
    )
    r(
        b"NSObject",
        b"pushRegistry:didUpdatePushCredentials:forType:",
        {
            "required": True,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE



import sys

from PyObjCTools.TestSupport import TestCase, min_os_level

if sys.maxsize > 2 ** 32:
    import PushKit

    class TestPKPushCredentials(TestCase):
        @min_os_level("10.15")
        def test_classes(self):
            PushKit.PKPushCredentials
